@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 """
-mem8 CLI: Memory management for the orchestr8 ecosystem.
+mem8 CLI: Memory management for team collaboration.
 
 This module provides the main entry point for the mem8 CLI, which has been
 migrated from Click to Typer for enhanced type safety and developer experience.
@@ -43,6 +43,11 @@ def main():
     
     # Import and run the Typer-based CLI
     from .cli_typer import typer_app
+    
+    # If no arguments provided, default to 'status' command
+    if len(sys.argv) == 1:
+        sys.argv.append('status')
+    
     typer_app()
 
 
